@@ -19,7 +19,7 @@ my @set = (
 );
 
 cmpthese 0, {
-    'Set::Crossproduct' => sub {
+    'Set::CrossProduct' => sub {
         my $it = Set::CrossProduct->new(\@set);
         while (my @s = $it->get) {
             my $str = "@s";
@@ -65,13 +65,13 @@ __END__
 
 =head1 BENCHMARKS
 
-                                        Rate Set::Crossproduct    List::Gen Algorithm::Loops   Set::Scalar Math::Cartesian::Product Set::Product::PP Set::Product::XS
-    Set::Crossproduct           45.1+-0.62/s                --       -28.7%           -38.1%        -59.6%                   -77.6%           -84.2%           -95.9%
-    List::Gen                  63.21+-0.42/s        40.2+-2.2%           --           -13.3%        -43.4%                   -68.7%           -77.8%           -94.3%
-    Algorithm::Loops           72.87+-0.34/s        61.6+-2.4% 15.29+-0.94%               --        -34.8%                   -63.9%           -74.5%           -93.4%
-    Set::Scalar               111.75+-0.18/s       147.8+-3.5%   76.8+-1.2%     53.35+-0.77%            --                   -44.6%           -60.8%           -89.9%
-    Math::Cartesian::Product    201.7+-2.8/s       347.2+-8.8%    219.1+-5%      176.8+-4.1%    80.5+-2.6%                       --           -29.3%           -81.8%
-    Set::Product::PP          285.25+-0.12/s       532.5+-8.8%    351.3+-3%      291.4+-1.9% 155.27+-0.44%                 41.4+-2%               --           -74.2%
-    Set::Product::XS         1106.72+-0.52/s         2354+-34%    1651+-12%     1418.7+-7.2%   890.4+-1.7%              448.7+-7.7%           288.0%               --
+                                        Rate Set::CrossProduct    List::Gen Algorithm::Loops Set::Scalar Math::Cartesian::Product Set::Product::PP Set::Product::XS
+    Set::CrossProduct          45.06+-0.54/s                --       -27.2%           -35.8%      -53.3%                   -78.8%           -84.1%           -95.5%
+    List::Gen                  61.94+-0.22/s        37.4+-1.7%           --           -11.8%      -35.8%                   -70.9%           -78.2%           -93.8%
+    Algorithm::Loops           70.25+-0.55/s        55.9+-2.2% 13.41+-0.97%               --      -27.2%                   -66.9%           -75.2%           -93.0%
+    Set::Scalar                  96.5+-1.7/s       114.2+-4.6%   55.8+-2.9%       37.4+-2.7%          --                   -54.6%           -66.0%           -90.4%
+    Math::Cartesian::Product      212.5+-2/s       371.6+-7.1%  243.1+-3.4%      202.5+-3.7% 120.2+-4.5%                       --           -25.0%           -78.8%
+    Set::Product::PP          283.52+-0.34/s       529.1+-7.5%  357.7+-1.7%      303.6+-3.2% 193.7+-5.3%               33.4+-1.2%               --           -71.7%
+    Set::Product::XS         1003.05+-0.21/s         2126+-26% 1519.4+-5.8%        1328+-11%    939+-19%                372+-4.4%    253.79+-0.43%               --
 
 =cut
