@@ -6,7 +6,7 @@ use warnings;
 use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.02';
+our $VERSION    = '0.03';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -49,13 +49,13 @@ This distribution contains a benchmarking script which compares several
 modules available on CPAN. These are the results on a MacBook 2.6GHz Core i5
 (64-bit) with Perl 5.22.0:
 
-    Set::Crossproduct           45.1+-0.62/s
-    List::Gen                  63.21+-0.42/s
-    Algorithm::Loops           72.87+-0.34/s
-    Set::Scalar               111.75+-0.18/s
-    Math::Cartesian::Product    201.7+-2.8/s
-    Set::Product::PP          285.25+-0.12/s
-    Set::Product::XS         1106.72+-0.52/s
+    Set::CrossProduct          45.06+-0.54/s
+    List::Gen                  61.94+-0.22/s
+    Algorithm::Loops           70.25+-0.55/s
+    Set::Scalar                  96.5+-1.7/s
+    Math::Cartesian::Product      212.5+-2/s
+    Set::Product::PP          283.52+-0.34/s
+    Set::Product::XS         1003.05+-0.21/s
 
 =head1 SEE ALSO
 
